@@ -163,8 +163,12 @@ class __internal__:
         metadata = []
         result = {'metadata': metadata}
         for metadata_file in metadata_files:
-            if not os.path.exists(metadata_file):
-                result = __internal__.handle_error(-2, "Unable to access metadata file '%s'" % metadata_file)
+            if hasattr(metadata_file, 'name'):
+                if not metadata_file.closed:
+                    metadata_file.close()
+                metadata_file = metadata_file.name
+            if not os.path.exists(str(metadata_file)):
+                result = __internal__.handle_error(-2, "Unable to access metadata file '%s'" % metadata_file.name)
                 break
             logging.info("Loading metadata from file: '%s'", metadata_file)
             md_loaded = __internal__.load_metadata(metadata_file)
@@ -326,12 +330,19 @@ class __internal__:
                 print(json.dumps(result, indent=2))
             if 'file' in type_parts or 'all' in type_parts:
                 if result_file_path:
-                    os.makedirs(os.path.dirname(result_file_path), exist_ok=True)
+                    try:
+                        os.makedirs(os.path.dirname(result_file_path), exist_ok=True)
+                    except OSError:
+                        msg = 'Error while creating result path "%s"' % str(os.path.dirname(result_file_path))
+                        logging.error(msg)
+                        if logging.getLogger().level == logging.DEBUG:
+                            logging.debug('Error creating folder for result file')
+                        logging.warning('Unable to create folders, skipping writing to result file')
                     with open(result_file_path, 'w') as out_file:
                         json.dump(result, out_file, indent=2)
                 else:
                     logging.warning("Writing result to a file was requested but a file path wasn't provided.")
-                    logging.warning("    Skipping writing to a file.")
+                    logging.warning("    Skipping writing to result file.")
 
         return result
 
@@ -343,20 +354,21 @@ def add_parameters(parser: argparse.ArgumentParser, algorithm_instance: Algorith
         algorithm_instance: working Transformer instance
         environment_instance: the current Environment
     """
-    parser.add_argument('--debug', '-d', action='store_const',
+    parser.add_argument('-d', '--debug', action='store_const',
                         default=logging.WARN, const=logging.DEBUG,
                         help='enable debug logging (default=WARN)')
 
-    parser.add_argument('--info', '-i', action='store_const',
+    parser.add_argument('-i', '--info', action='store_const',
                         default=logging.WARN, const=logging.INFO,
                         help='enable info logging (default=WARN)')
 
     parser.add_argument('--result', nargs='?', default='all',
                         help='Direct the result of a run to one or more of (all is default): "all,file,print"')
 
-    parser.add_argument('--metadata', type=str, action='append', help='The path to the source metadata')
+    parser.add_argument('-m', '--metadata', type=argparse.FileType('rt'), action='append',
+                        help='The path to the source metadata')
 
-    parser.add_argument('--working_space', type=str,
+    parser.add_argument('-w', '--working_space', type=str, default='output',
                         help='the folder to use use as a workspace and for storing results')
 
     # Let the transformer class add parameters
@@ -368,7 +380,9 @@ def add_parameters(parser: argparse.ArgumentParser, algorithm_instance: Algorith
         algorithm_instance.add_parameters(parser)
 
     # Assume the rest of the arguments are the files
-    parser.add_argument('file_list', nargs=argparse.REMAINDER, help='additional files for transformer')
+    parser.add_argument('file_list', nargs='*', type=argparse.FileType('r'),
+                        help='additional files, folders, and other information'
+                             ' for the transformer')
 
 
 def do_work(parser: argparse.ArgumentParser, configuration_info: Configuration,
@@ -387,13 +401,23 @@ def do_work(parser: argparse.ArgumentParser, configuration_info: Configuration,
     if not transformer_instance:
         result = __internal__.handle_error(-100, "Unable to create transformer class instance for processing")
         return __internal__.handle_result(result, None, None)
-
     add_parameters(parser, algorithm_instance, transformer_instance)
     args = parser.parse_args()
 
     # start logging system
     logging.getLogger().setLevel(args.debug if args.debug == logging.DEBUG else args.info)
 
+    if args.working_space and not os.path.isdir(args.working_space):
+        try:
+            os.makedirs(args.working_space)
+        except OSError:
+            msg = 'Error while creating working space path "%s"' % str(args.working_space)
+            logging.warning(msg)
+            if logging.getLogger().level == logging.DEBUG:
+                logging.debug('Error creating working space path')
+            result = __internal__.handle_error(-10, msg)
+            return __internal__.handle_result(result, None, None)
+
     # Check that we have metadata
     if not args.metadata and __internal__.check_metadata_needed(configuration_info):
         result = __internal__.handle_error(-1, "No metadata paths were specified.")
@@ -422,5 +446,14 @@ def entrypoint(configuration_info: Configuration, algorithm_instance: Algorithm)
         configuration_info: an instance of Configuration class
         algorithm_instance: an instance of class for preparing work
     """
+    begin_process(configuration_info, algorithm_instance)
+
+
+def begin_process(configuration_info: Configuration, algorithm_instance: Algorithm):
+    """entrypoint() functionality moved here to allow users to transition over time
+    Arguments:
+        configuration_info: an instance of the Configuration class
+        algorithm_instance: an instance of class for preparing work
+    """
     parser = argparse.ArgumentParser(description=configuration_info.transformer_description)
     do_work(parser, configuration_info, algorithm_instance)
