@@ -6,13 +6,15 @@ import subprocess
 from typing import Optional
 import logging
 import numpy as np
-
+import osgeo
 from osgeo import gdal
 from osgeo import ogr
 from osgeo import osr
 
 import agpypeline.geometries as geometries
 
+LAT_LON_EPSG_CODE = 4326
+
 
 def clip_raster(raster_path: str, bounds: tuple, out_path: str = None, compress: bool = True) -> Optional[np.ndarray]:
     """Clip raster to polygon
@@ -132,6 +134,7 @@ def create_geotiff(pixels: np.ndarray, gps_bounds: tuple, out_path: str, srid: i
         gps_bounds: tuple of GeoTIFF coordinates as ( lat (y) min, lat (y) max,
                                                         long (x) min, long (x) max)
         out_path: path to GeoTIFF to be created
+        srid: the SRID of the geographic system to assign to the image
         nodata: NoDataValue to be assigned to raster bands; set to None to ignore
         as_float: whether to use GDT_Float32 data type instead of GDT_Byte (e.g. for decimal numbers)
         image_md: metadata to save with the geotiff
@@ -159,9 +162,9 @@ def create_geotiff(pixels: np.ndarray, gps_bounds: tuple, out_path: str, srid: i
     dtype = gdal.GDT_Float32 if as_float else gdal.GDT_Byte
 
     if compress:
-        output_raster = gdal.GetDriverByName('GTiff') .Create(out_path, ncols, nrows, channels, dtype, ['COMPRESS=LZW'])
+        output_raster = gdal.GetDriverByName('GTiff') .Create(out_path, ncols, nrows, channels, dtype, ['COMPRESS=LZW', 'PREDICTOR=2'])
     else:
-        output_raster = gdal.GetDriverByName('GTiff').Create(out_path, ncols, nrows, channels, dtype)
+        output_raster = gdal.GetDriverByName('GTiff').Create(out_path, ncols, nrows, channels, dtype, ['BIGTIFF=YES'])
 
     output_raster.SetGeoTransform(geotransform)
     srs = osr.SpatialReference()
@@ -170,26 +173,16 @@ def create_geotiff(pixels: np.ndarray, gps_bounds: tuple, out_path: str, srid: i
 
     output_raster.SetMetadata(image_md)
 
-    if channels == 3:
-        # typically 3 channels = RGB channels
-        output_raster.GetRasterBand(1).WriteArray(pixels[:, :, 0].astype('uint8'))
-        output_raster.GetRasterBand(1).SetColorInterpretation(gdal.GCI_RedBand)
-        output_raster.GetRasterBand(1).FlushCache()
-        if nodata:
-            output_raster.GetRasterBand(1).SetNoDataValue(nodata)
-
-        output_raster.GetRasterBand(2).WriteArray(pixels[:, :, 1].astype('uint8'))
-        output_raster.GetRasterBand(2).SetColorInterpretation(gdal.GCI_GreenBand)
-        output_raster.GetRasterBand(2).FlushCache()
-        if nodata:
-            output_raster.GetRasterBand(2).SetNoDataValue(nodata)
-
-        output_raster.GetRasterBand(3).WriteArray(pixels[:, :, 2].astype('uint8'))
-        output_raster.GetRasterBand(3).SetColorInterpretation(gdal.GCI_BlueBand)
-        output_raster.GetRasterBand(3).FlushCache()
-        if nodata:
-            output_raster.GetRasterBand(3).SetNoDataValue(nodata)
-
+    if channels in [3, 4]:
+        # RGB and RGBA channels
+        channel_types = [gdal.GCI_RedBand, gdal.GCI_GreenBand, gdal.GCI_BlueBand, gdal.GCI_AlphaBand]
+        for chan in range(channels):
+            band = chan + 1
+            output_raster.GetRasterBand(band).WriteArray(pixels[:, :, chan].astype('uint8'))
+            output_raster.GetRasterBand(band).SetColorInterpretation(channel_types[chan])
+            output_raster.GetRasterBand(band).FlushCache()
+            if nodata:
+                output_raster.GetRasterBand(band).SetNoDataValue(nodata)
     elif channels > 1:
         for chan in range(channels):
             band = chan + 1
@@ -205,6 +198,55 @@ def create_geotiff(pixels: np.ndarray, gps_bounds: tuple, out_path: str, srid: i
             output_raster.GetRasterBand(1).SetNoDataValue(nodata)
 
 
+def get_centroid_latlon(filename: str) -> ogr.Geometry:
+    """Returns the bounds and epsg of a geo-referenced image file
+    Arguments:
+        filename: the path to the file to get the centroid from
+    Returns:
+        Returns the centroid of the geometry loaded from the file in lat-lon coordinates
+        as a result of calling geometries.get_centroid_latlon()
+    Exceptions:
+        RuntimeError is raised if the image is not a geo referenced image with an EPSG code,
+        the EPSG code is not supported, or another problems occurs
+    """
+    epsg = get_epsg(filename)
+
+    poly = get_image_bounds(filename, epsg)
+    if poly is None:
+        msg = "File is not a geo-referenced image file: %s" % filename
+        logging.error(msg)
+        raise RuntimeError(msg)
+    if epsg is None:
+        msg = "EPSG is not found in image file: '%s'" % filename
+        logging.error(msg)
+        raise RuntimeError(msg)
+    # Convert the polygon to lat-lon
+    dest_spatial = osr.SpatialReference()
+    if int(osgeo.__version__[0]) >= 3:
+        # GDAL 3 changes axis order: https://github.com/OSGeo/gdal/issues/1546
+        # pylint: disable=no-member
+        dest_spatial.SetAxisMappingStrategy(osgeo.osr.OAMS_TRADITIONAL_GIS_ORDER)
+
+    if dest_spatial.ImportFromEPSG(int(LAT_LON_EPSG_CODE)) != ogr.OGRERR_NONE:
+        msg = "Failed to import EPSG %s for conversion to lat-lon" % str(LAT_LON_EPSG_CODE)
+        logging.error(msg)
+        raise RuntimeError(msg)
+    ref_sys = osr.SpatialReference()
+    if ref_sys.ImportFromEPSG(int(epsg)) != ogr.OGRERR_NONE:
+        msg = "Failed to import EPSG %s for conversion to lat-lon" % str(epsg)
+        logging.error(msg)
+        raise RuntimeError(msg)
+    transform = osr.CoordinateTransformation(ref_sys, dest_spatial)
+    new_src = poly.Clone()
+    if new_src:
+        new_src.Transform(transform)
+    else:
+        msg = "Failed to transform file polygon to lat-lon" % filename
+        logging.error(msg)
+        raise RuntimeError(msg)
+    return new_src.Centroid()
+
+
 def get_epsg(filename: str) -> Optional[str]:
     """Returns the EPSG of the georeferenced image file
     Args:
@@ -229,6 +271,7 @@ def get_image_bounds(file_path: str, default_epsg: int = None) -> Optional[ogr.G
     Arguments:
         file_path: path to the file from which to load the bounds
         default_epsg: the default EPSG to assume if a file has a boundary but not a coordinate system
+        as a result of calling geometries.polygon_from_ring
     Return:
         Returns the geometry representing the image boundary, or None if the
         bounds could not be loaded
@@ -240,7 +283,7 @@ def get_image_bounds(file_path: str, default_epsg: int = None) -> Optional[ogr.G
     """
     # Get the bounds (if they exist)
     bounds = image_get_geobounds(file_path)
-    if bounds[0] == np.nan:
+    if np.nan in bounds:
         return None
 
     epsg = get_epsg(file_path)
@@ -258,7 +301,6 @@ def get_image_bounds(file_path: str, default_epsg: int = None) -> Optional[ogr.G
     ring.AddPoint(bounds[3], bounds[0])  # lower right
     ring.AddPoint(bounds[2], bounds[0])  # lower left
     ring.AddPoint(bounds[2], bounds[1])  # Closing the polygon
-
     return geometries.polygon_from_ring(ring, int(epsg))
 
 
